==> logback_0.9.15.orig.tar.gz: logback-0.9.15/docs/templates/creative.js <==
document.write('		<table style="margin-left: 0em; padding-top=0ex" cellpadding="0" ');
document.write('           cellspacing="0" width="70%">');
document.write('      <tr>');
document.write('        <td>        ');
document.write('          <p class="author">');
document.write('            Authors: Ceki G&#252;lc&#252;, S&#233;bastien Pennec');
document.write('          <br/>');
document.write('          Copyright &#169; 2000-2008, QOS.ch</p>');
document.write('        </td>');
document.write('        <td>');
document.write('            <a rel="license"');
document.write('               href="http://creativecommons.org/licenses/by-nc-sa/2.5/">');
document.write('        <img alt="Creative Commons License"');
document.write('             style="border-width: 0; margin-left: 1em"');
document.write('             src="http://creativecommons.org/images/public/somerights20.png" />');
document.write('          </a>');
document.write('        </td>');
document.write('      </tr>');
document.write('      <tr>');
document.write('        <td>');
document.write('          <p>');
document.write('            This document is licensed under a');
document.write('            <a rel="license"');
document.write('               href="http://creativecommons.org/licenses/by-nc-sa/2.5/">');
document.write('              Creative Commons');
document.write('              Attribution-NonCommercial-ShareAlike 2.5');
document.write('              License');
document.write('            </a>');
document.write('          </p>');
document.write('        </td>');
document.write('        <td></td>');
document.write('			</tr>');
document.write('		</table>');

==> logback_1.0.4.orig.tar.gz: logback_1.0.4/docs/templates/creative.js <==
document.write('		<table style="margin-left: 0em; padding-top:0ex" cellpadding="0" ');
document.write('           cellspacing="0" width="70%">');
document.write('      <tr>');
document.write('        <td>        ');
document.write('          <p class="author">');
document.write('            Authors: Ceki G&#252;lc&#252;, S&#233;bastien Pennec');
document.write('          <br/>');
document.write('          Copyright &#169; 2000-2012, QOS.ch</p>');
document.write('        </td>');
document.write('        <td>');
document.write('            <a rel="license"');
document.write('               href="http://creativecommons.org/licenses/by-nc-sa/2.5/">');
document.write('        <img alt="Creative Commons License"');
document.write('             style="border-width: 0; margin-left: 1em"');
document.write('             src="http://creativecommons.org/images/public/somerights20.png" />');
document.write('          </a>');
document.write('        </td>');
document.write('      </tr>');
document.write('      <tr>');
document.write('        <td>');
document.write('          <p>');
document.write('            This document is licensed under a');
document.write('            <a rel="license"');
document.write('               href="http://creativecommons.org/licenses/by-nc-sa/2.5/">');
document.write('              Creative Commons');
document.write('              Attribution-NonCommercial-ShareAlike 2.5');
document.write('              License');
document.write('            </a>');
document.write('          </p>');
document.write('        </td>');
document.write('        <td></td>');
document.write('			</tr>');
document.write('		</table>');
